==> qliksense-extension-tutorial-0.9.0.tgz: package/tutorial/part-01/00-About.md <==
# About this tutorial



**Table of Contents**

<!-- toc -->

- [Folder structure for sample code](#folder-structure-for-sample-code)

<!-- tocstop -->

---


In the past I was writing quite a lot of article on [my private blog](http://www.qlikblog.at) which is fine in general, but when writing a tutorial, a blog is not really the ideal format as I realized.

So it's time to try something new: ***A living tutorial***.

The main idea behind publishing this tutorial to [GitHub](http://github.com) is, that a really good tutorial should probably never be finished. If there are changes to be made (either in the code or the descriptive text), it should just be easy to make these changes and publish them. Certainly not only for me - the primary author - but also for other people.

So I invite you not only to consume but also to participate!

This initiative is somehow related to one of the articles I have written two years ago: [Plea for Open Source Development in the Qlik(View) World](http://www.qlikblog.at/3040/plea-for-open-source-development-in-the-qlikview-world/)

## Folder structure for sample code

If there is some code related to a chapter, the code folder is always structured the same way:

Folder				| Description
-------------------	| -------------------------------------------------------------
**build**			| Folder containing a zip-file called *_latest.zip with the latest version
**dist**			| Introduced in later chapters
**grunt**			| Grunt tasks for my internal deployment system, you can ignore it as of now. I'll talk about it in some of the later chapters.
**src**				| The **source code** used for the given chapter



---
**Qlik Sense Visualization Extension Tutorial**, Version 0.9.0<br/>
Last update: 2015-05-29<br/>

[Overview of all chapters](https://github.com/stefanwalther/qliksense-extension-tutorial/blob/master/tutorial/readme.md)

==> qliksense-extension-tutorial-0.12.7.tgz: package/tutorial/part-01/00-About.md <==
# About this tutorial



**Table of Contents**

<!-- toc -->

- [Folder structure for sample code](#folder-structure-for-sample-code)

<!-- tocstop -->

---


In the past I was writing quite a lot of article on [my private blog](http://qliksite.io) which is fine in general, but when writing a tutorial, a blog is not really the ideal format as I realized.

So it's time to try something new: ***A living tutorial***.

The main idea behind publishing this tutorial to [GitHub](http://github.com) is, that a really good tutorial should probably never be finished. If there are changes to be made (either in the code or the descriptive text), it should just be easy to make these changes and publish them. Certainly not only for me - the primary author - but also for other people.

So I invite you not only to consume but also to participate!

This initiative is somehow related to one of the articles I have written two years ago: [Plea for Open Source Development in the Qlik(View) World](http://www.qlikblog.at/3040/plea-for-open-source-development-in-the-qlikview-world/)

## Folder structure for sample code

If there is some code related to a chapter, the code folder is always structured the same way:

Folder				| Description
-------------------	| -------------------------------------------------------------
**build**			| Folder containing a zip-file called *_latest.zip with the latest version
**dist**			| Introduced in later chapters
**grunt**			| Grunt tasks for my internal deployment system, you can ignore it as of now. I'll talk about it in some of the later chapters.
**src**				| The **source code** used for the given chapter



---
**Qlik Sense Visualization Extension Tutorial**, Version 0.12.7<br/>
Last update: 2015-05-29<br/>

[Overview of all chapters](https://github.com/stefanwalther/qliksense-extension-tutorial/blob/master/tutorial/readme.md)
